View source: R/audubon-package.R
| default_format | R Documentation |
Returns the default date format string used for Japanese calendar date parsing and formatting.
This helper function exists to provide a UTF-8 encoded format string without embedding non-ASCII characters directly in function defaults.
default_format()
A character string representing a Japanese calendar date format.
default_format()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.