| read_rewrite_def | R Documentation |
Reads a rewrite definition file used for Japanese text normalization.
This function parses a tab-delimited definition file and returns a list
of rewrite rules and ignored characters suitable for use with
strj_rewrite_as_def().
read_rewrite_def(
def_path = system.file("def/rewrite.def", package = "audubon")
)
def_path |
A file path to a rewrite definition file. |
A list containing rewrite rules and ignored characters.
str(read_rewrite_def())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.